@@ -1,5 +1,18 @@
 scoring.QLQLC13 <-
-function(X,id="",items=1:13){
+function(X,id="",time=""){
+
+items=paste("q",31:43,sep="")
+
+if(length(which(is.element(items,colnames(X))))<13){
+stop("At least one item is missing: items must be named q31 to q43");
+break
+}
+
+if(length(which(match(items,colnames(X))==sort(match(items,colnames(X)))))<13){
+stop("Items must be named q31 to q43 and presented on that order in the dataset");
+break
+}
+
 if(sum(apply(X[,items],2,is.integer))<13){
 stop("Items must be integer");
 break
@@ -14,16 +27,34 @@ if(max(X[,items],na.rm=T)>4){
 stop("Maximum possible value for items is 4");
 break
 }
-if(id!=""){
+
+if((id!="")&(time!="")){
+Y=matrix(nrow=nrow(X),ncol=12)
+Y=as.data.frame(Y)
+Y[,1]=X[,id]
+Y[,2]=X[,time]
+colnames(Y)=c(id,time,"LCDY","LCCO","LCHA","LCSM","LCDS","LCPN","LCHR","LCPC","LCPA","LCPO")
+}
+
+if((id!="")&(time=="")){
 Y=matrix(nrow=nrow(X),ncol=11)
 Y=as.data.frame(Y)
 Y[,1]=X[,id]
-
 colnames(Y)=c(id,"LCDY","LCCO","LCHA","LCSM","LCDS","LCPN","LCHR","LCPC","LCPA","LCPO")
-}else{
+}
+
+if((id=="")&(time!="")){
+Y=matrix(nrow=nrow(X),ncol=11)
+Y=as.data.frame(Y)
+Y[,1]=X[,time]
+colnames(Y)=c(time,"LCDY","LCCO","LCHA","LCSM","LCDS","LCPN","LCHR","LCPC","LCPA","LCPO")
+}
+
+if((id=="")&(time=="")){
 Y=matrix(nrow=nrow(X),ncol=10)
 Y=as.data.frame(Y)
-colnames(Y)=c("LCDY","LCCO","LCHA","LCSM","LCDS","LCPN","LCHR","LCPC","LCPA","LCPO")}
+colnames(Y)=c("LCDY","LCCO","LCHA","LCSM","LCDS","LCPN","LCHR","LCPC","LCPA","LCPO")
+}
 DM_LCDY=apply(is.na(X[,items[3:5]]),1,sum)
 rs_LCDY=apply(X[,items[3:5]],1,sum,na.rm=TRUE)
 rs_LCDY=rs_LCDY/(3-DM_LCDY)
